//______________________________________________________________________________
// ImagePlanePlugin
// 2009/09/29 by Eugen Sares
// last revision: 2011/10/03
//
// Select an Image Source in the Explorer first (Filter: Sources/Clips, Keyshort O),
// then run this Script.
// It creates a Grid Primitive with the correct proportions, Constant Shader and
// Texture Support.
//______________________________________________________________________________

function XSILoadPlugin( in_reg )
{
	in_reg.Author = "Eugen Sares";
	in_reg.Name = "ImagePlanePlugin";
	in_reg.Major = 1;
	in_reg.Minor = 0;

	in_reg.RegisterCommand("ImagePlane","ImagePlane");
	//RegistrationInsertionPoint - do not remove this line
	in_reg.RegisterMenu(siMenuAnchorPoints.siMenuTbGetPrimitivePolygonMeshID,'ImagePlane_Menu', false, true)


	return true;
}

function XSIUnloadPlugin( in_reg )
{
	var strPluginName;
	strPluginName = in_reg.Name;
	Application.LogMessage(strPluginName + " has been unloaded.",siVerbose);
	return true;
}

function ImagePlane_Init( in_ctxt )
{
	var oCmd;
	oCmd = in_ctxt.Source;
	oCmd.Description = "Create textured Grid from Image Clip";
	oCmd.Tooltip = "ImagePlane";
	oCmd.ReturnValue = true;

	return true;
}


//______________________________________________________________________________

function ImagePlane_Execute(  )
{

	Application.LogMessage("ImagePlane_Execute called",siVerbose);

	try {
		if(Selection.count == 0)
			throw "Please select an Image Clip first.";

		var cImageClips = Selection;
		
		for(var i = 0; i < cImageClips.Count; i++)
		{
			var oImageClip = Application.Selection(i);
			if(oImageClip.Type != "ImageClip")
				continue;
				//throw "Please select an Image Clip first.";
			
			var oImageSource = oImageClip.Source;
			xres = oImageSource.Parameters("XRes").Value;
			yres = oImageSource.Parameters("YRes").Value;


			// Create Grid
			var oRoot = ActiveProject.ActiveScene.Root;
			var oPictureGrid = oRoot.AddGeometry( "Grid", "MeshSurface" );
			SetValue(oPictureGrid.Name + ".polymsh.geom.subdivu", 2);
			SetValue(oPictureGrid.Name + ".polymsh.geom.subdivv", 2);

			var vlen = oPictureGrid.Parameters("vlength").Value;
			vlen *= yres/xres;
			SetValue(oPictureGrid + ".grid.vlength", vlen, null);
			
			
			// Create Material
			var oImageSourceName = "Clips." + oImageSource.Name;

			var oMaterial = oPictureGrid.AddMaterial("Constant");
			var oMaterialName = ActiveProject.ActiveScene.ActiveMaterialLibrary + "." + oMaterial.Name;

			// Put Image into Material
			NestShaders(oImageSourceName, oMaterialName);
			
			// Connect Image to Constant Color
			SIConnectShaderToCnxPoint(oImageSourceName, oMaterialName + ".Constant.color");


			// Create Texture Projection
			oProjection = CreateProjection(oPictureGrid, siTxtPlanarXZ, siTxtDefaultPlanarXZ, "", 
				"Texture_Projection", null, siRelDefault, "");
		}
	}

catch(e)
	{
		Application.LogMessage(e, siWarning);
	}

	return true;
}


//______________________________________________________________________________

function ImagePlane_Menu_Init( in_ctxt )
{
	oMenu = in_ctxt.Source;
    oMenu.AddCommandItem("ImagePlane","ImagePlane");
    return true;
}
